==> haskell-random-fu-0.3.0.1-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-fu
version:              0.3.0.1
visibility:           public
id:                   random-fu-0.3.0.1-9IijliowMO87hVGjd3MZLj
key:                  random-fu-0.3.0.1-9IijliowMO87hVGjd3MZLj
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  163cbbab504371f62a22a4604c80425d
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-fu-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-fu
hs-libraries:         HSrandom-fu-0.3.0.1-9IijliowMO87hVGjd3MZLj
depends:
    base-4.17.2.1 erf-2.0.0.0-Eu7AY88UyC43DyrUue97pz
    math-functions-0.3.4.4-2n51o8reQfp27kUCJfBpt6
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    random-shuffle-0.0.4-944phXfQLEn5beTVmH4gOm
    rvar-0.3.0.2-52JB8b8hVyrI87bAnkgXuT
    syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt template-haskell-2.19.0.0
    transformers-0.5.6.2 vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-fu-0.3.0.1-129-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-fu
version:              0.3.0.1
visibility:           public
id:                   random-fu-0.3.0.1-1RPiB03TQhUD55vk2PdXX8
key:                  random-fu-0.3.0.1-1RPiB03TQhUD55vk2PdXX8
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  25a3a255592ce035a22ffdf19bfe45ec
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/random-fu-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/random-fu-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/random-fu-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-fu
hs-libraries:         HSrandom-fu-0.3.0.1-1RPiB03TQhUD55vk2PdXX8
depends:
    base-4.18.3.0 erf-2.0.0.0-4hvyEg8FAX833lNnLepC9w
    math-functions-0.3.4.4-IOpsyV3H35o8lt7KgtSzED
    monad-loops-0.4.3-5l0VsAe9uQp4kipHCeMw4i mtl-2.3.1
    random-1.2.1.3-GswEfj1SZ276IcAtylwQ0f
    random-shuffle-0.0.4-9NcmHCrGj6kBpfiWsiNBFn
    rvar-0.3.0.2-AZI5TQcLKNXKP4I8yLxTiV
    syb-0.7.3-4faDNy9a4q18QDGKds5is3 template-haskell-2.20.0.0
    transformers-0.6.1.0 vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
